| get_parameter_dims | R Documentation |
Extracts the names and dimensions of all parameters used in the
dynamite model. See also get_parameter_types() and
get_parameter_names(). The returned dimensions match those of
the stanfit element of the dynamitefit object. When applied to
dynamiteformula objects, the model is compiled and sampled for 1 iteration
to get the parameter dimensions.
get_parameter_dims(x, ...)
## S3 method for class 'dynamiteformula'
get_parameter_dims(x, data, time, group = NULL, ...)
## S3 method for class 'dynamitefit'
get_parameter_dims(x, ...)
x |
[ |
... |
Ignored. |
data |
[ |
time |
[ |
group |
[ |
A named list with all parameter dimensions of the input model.
Model outputs
as.data.frame.dynamitefit(),
as.data.table.dynamitefit(),
as_draws_df.dynamitefit(),
coef.dynamitefit(),
confint.dynamitefit(),
dynamite(),
get_code(),
get_data(),
get_parameter_names(),
get_parameter_types(),
ndraws.dynamitefit(),
nobs.dynamitefit()
data.table::setDTthreads(1) # For CRAN
get_parameter_dims(multichannel_example_fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.