| get_parameter_types | R Documentation |
Extracts all parameter types of used in the dynamitefit object. See
as.data.frame.dynamitefit() for explanations of different types.
get_parameter_types(x, ...)
## S3 method for class 'dynamitefit'
get_parameter_types(x, ...)
x |
[ |
... |
Ignored. |
A character vector with all parameter types of the input model.
Model outputs
as.data.frame.dynamitefit(),
as.data.table.dynamitefit(),
as_draws_df.dynamitefit(),
coef.dynamitefit(),
confint.dynamitefit(),
dynamite(),
get_code(),
get_data(),
get_parameter_dims(),
get_parameter_names(),
ndraws.dynamitefit(),
nobs.dynamitefit()
data.table::setDTthreads(1) # For CRAN
get_parameter_types(multichannel_example_fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.