| ndraws.dynamitefit | R Documentation |
dynamitefit ObjectReturn the Number of Posterior Draws of a dynamitefit Object
## S3 method for class 'dynamitefit'
ndraws(x)
x |
[ |
Number of posterior draws as a single integer value.
Model outputs
as.data.frame.dynamitefit(),
as.data.table.dynamitefit(),
as_draws_df.dynamitefit(),
coef.dynamitefit(),
confint.dynamitefit(),
dynamite(),
get_code(),
get_data(),
get_parameter_dims(),
get_parameter_names(),
get_parameter_types(),
nobs.dynamitefit()
data.table::setDTthreads(1) # For CRAN
ndraws(gaussian_example_fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.