| splines | R Documentation |
This function can be used as part of dynamiteformula() to define the
splines used for the time-varying coefficients \delta.
splines(
df = NULL,
degree = 3L,
lb_tau = 0,
noncentered = FALSE,
override = FALSE
)
df |
[ |
degree |
[ |
lb_tau |
[ |
noncentered |
[ |
override |
[ |
An object of class splines.
Model formula construction
dynamite(),
dynamiteformula(),
lags(),
lfactor(),
random_spec()
data.table::setDTthreads(1) # For CRAN
# Two channel model with varying effects, with explicit lower bounds for the
# random walk prior standard deviations, with noncentered parameterization
# for the first channel and centered for the second channel.
obs(y ~ 1, family = "gaussian") + obs(x ~ 1, family = "gaussian") +
lags(type = "varying") +
splines(
df = 20, degree = 3, lb_tau = c(0, 0.1),
noncentered = c(TRUE, FALSE)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.