| as_draws_df.dynamitefit | R Documentation |
dynamite Output to draws_df FormatConverts the output from a dynamite() call to a
draws_df format of the posterior package, enabling the use
of diagnostics and plotting methods of posterior and bayesplot
packages. Note that this function returns variables in a wide format,
whereas as.data.frame.dynamitefit() uses the long format.
## S3 method for class 'dynamitefit'
as_draws_df(
x,
parameters = NULL,
responses = NULL,
types = NULL,
times = NULL,
groups = NULL,
...
)
## S3 method for class 'dynamitefit'
as_draws(x, parameters = NULL, responses = NULL, types = NULL, ...)
x |
[ |
parameters |
[ |
responses |
[ |
types |
[ |
times |
[ |
groups |
[ |
... |
Ignored. |
You can use the arguments parameters, responses and types to extract
only a subset of the model parameters (i.e., only certain types of
parameters related to a certain response variable).
See potential values for the types argument in as.data.frame.dynamitefit()
and get_parameter_names() for potential values for parameters argument.
A draws_df object.
A draws_df object.
Model outputs
as.data.frame.dynamitefit(),
as.data.table.dynamitefit(),
coef.dynamitefit(),
confint.dynamitefit(),
dynamite(),
get_code(),
get_data(),
get_parameter_dims(),
get_parameter_names(),
get_parameter_types(),
ndraws.dynamitefit(),
nobs.dynamitefit()
data.table::setDTthreads(1) # For CRAN
as_draws(gaussian_example_fit, types = c("sigma", "beta"))
# Compute MCMC diagnostics using the posterior package
posterior::summarise_draws(as_draws(gaussian_example_fit))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.