| dynamice | R Documentation |
Applies multiple imputation using mice::mice() to the supplied data
and fits a dynamic multivariate panel model to each imputed data set using
dynamite(). Posterior samples from each imputation run are
combined. When using wide format imputation, the long format data is
automatically converted to a wide format before imputation to preserve the
longitudinal structure, and then converted back to long format for
estimation.
dynamice(
dformula,
data,
time,
group = NULL,
priors = NULL,
backend = "rstan",
verbose = TRUE,
verbose_stan = FALSE,
stanc_options = list("O0"),
threads_per_chain = 1L,
grainsize = NULL,
custom_stan_model = NULL,
interval = 1L,
debug = NULL,
mice_args = list(),
impute_format = "wide",
keep_imputed = FALSE,
stan_csv_dir = tempdir(),
...
)
dformula |
[ |
data |
[ |
time |
[ |
group |
[ |
priors |
[ |
backend |
[ |
verbose |
[ |
verbose_stan |
[ |
stanc_options |
[ |
threads_per_chain |
[ |
grainsize |
[ |
custom_stan_model |
[ |
interval |
[ |
debug |
[ |
mice_args |
[ |
impute_format |
[ |
keep_imputed |
[ |
stan_csv_dir |
[ |
... |
For |
Model fitting
dynamite(),
get_priors(),
update.dynamitefit()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.